@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 10680 2017-12-26 02:57:55Z David $
+# $Id: models.py 10694 2017-12-29 09:22:09Z David $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2017-12-26 10:57:55 +0800 (Tue, 26 Dec 2017) $
-# $Revision: 10680 $
+# $Date: 2017-12-29 17:22:09 +0800 (Fri, 29 Dec 2017) $
+# $Revision: 10694 $
 
 from django.db import models
 from django.contrib.auth.models import User
@@ -21,7 +21,7 @@ from django.utils.translation import ugettext as _
 
 from Iuppiter.Model import BaseModelMixin
 
-from Theophrastus.models import Newsletter, MailingList
+from Theophrastus.models import Newsletter
 
 
 class Group(models.Model, BaseModelMixin):
@@ -91,14 +91,6 @@ class App(models.Model, BaseModelMixin):
         verbose_name = _('app')
         verbose_name_plural = _('apps')
 
-class AppMailingList(models.Model):
-    app = models.ForeignKey(App)
-    mailingList = models.ForeignKey(MailingList)
-
-class AppNewsletter(models.Model):
-    app = models.ForeignKey(App)
-    newsletter = models.ForeignKey(Newsletter)
-
 class GroupMappingTable(models.Model, BaseModelMixin):
 
     KEYWORD = 0
