@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: StatisticsHandler.py 10287 2017-09-11 02:58:59Z David $
+# $Id: StatisticsHandler.py 10696 2017-12-30 15:15:33Z David $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2017-09-11 10:58:59 +0800 (Mon, 11 Sep 2017) $
-# $Revision: 10287 $
+# $Date: 2017-12-30 23:15:33 +0800 (Sat, 30 Dec 2017) $
+# $Revision: 10696 $
 
 from datetime import timedelta, datetime
 
@@ -504,22 +504,24 @@ def getStatisticsTotalData(reqestGetData, subscriberCount, testSubscriberCount,
         newsletterIds = conditions.pop('newsletter__id__in')
 
         dataTmp = {}
+        # data structure of dataTmp is something like:
+        # {[u'2017-12-30', {'bounce': 0, 'click': 0, ...}], ...}
         for _id in newsletterIds:
             conditions.update({'newsletter__id': _id})
             _cs = getContactStatus(conditions)
+            _dateKey = _cs[0]['d']
             _statusCount = countStatus(_cs)[0]
-
+            dataTmp[_dateKey] = _statusCount
         # Merge.
         totalData = []
         for _dt in dataTmp:
             data = {}
             allDatas = dataTmp[_dt]
-            for _t in allDatas:
-                for _key in _t:
-                    v = _t[_key]
-                    if _key not in data:
-                        data[_key] = 0
-                    data[_key] += v
+            for _key in allDatas:
+                v = allDatas[_key]
+                if _key not in data:
+                    data[_key] = 0
+                data[_key] += v
             totalData.append([_dt, data])
     else:
         contactStatus = getContactStatus(conditions)
@@ -584,14 +586,17 @@ def getStatisticsTotalData(reqestGetData, subscriberCount, testSubscriberCount,
     else:
         def _do(info, subscriberCount, testSubscriberCount):
             rates = []
-            
+            newsletter = conditions['newsletter']
             for i in info:
                 if i in ('unsubscribe', 'deliverie', 'error'):
                     totalValue = subscriberCount
                 elif i == 'sentTest':
                     totalValue = testSubscriberCount
                 else:
-                    totalValue = info['deliverie']        
+                    totalValue = ContactMailingStatus.objects.filter(
+                                    newsletter=newsletter, 
+                                    status=ContactMailingStatus.SENT
+                                ).count()      
                 
                 value = percentage(info[i], totalValue, showPercent=False)
                 
